==> imagedb-api-4.5.0-20250825.085839-77.jar: image/db/sql/V20250223_1__alter_imageImportPlugin.sql <==
--修改成果影像入库插件
UPDATE tbimp_plugin
SET f_name='成果影像解析入库插件', f_group='文件', f_desc='成果影像解析入库插件', f_assembly=NULL, f_classname='com.geoway.imagedb.dataset.plugin.ImageMosaicDatasetImportPlugin', f_detail='<Plugin>
	<Design>

		<Param type="dropbox" multiple="false" text="目标数据库" name="TargetDatabaseKey" hideName="TargetDatabaseName" value="String" required="true">
			<Datasource type="datumDatabase" param="">

			</Datasource>
		</Param>

		<Param type="dropbox" multiple="false" text="目标要素集" name="DatasetId" value="Number" hideName="TargetFeatureDatasetName" required="true">
			<Datasource type="imageDataset" param="${TargetDatabaseKey}">

			</Datasource>
		</Param>

	</Design>
	<Run>
		<Param type="dropbox" multiple="false" text="文件结构模型" name="FileModelId" value="String" required="true">
			<Datasource type="datasetFileModel" param="${DatasetId}" required="true">

			</Datasource>
		</Param>
		<Param type="dropbox" multiple="false" text="存储节点" name="ServiceId" value="String" required="true">
			<Datasource type="datasetFileStorage" param="${DatasetId}" required="true">

			</Datasource>
		</Param>
		<Param type="file" multiple="false" text="数据位置" name="SourceFolderPath" value="String" required="true">
			<Datasource type="enum" param="${ServiceId}">
				<option value="1" text="Folder" />
			</Datasource>
		</Param>
		<Param type="dropbox" multiple="false" text="元数据解析插件" name="MetaPluginInfo" required="false">
			<Datasource type="imageMetaPluginInfo" required="true">

			</Datasource>
		</Param>
		<Param type="datePicker" text="数据时相" name="Time" value="Date" needSecond="false" required="false">

		</Param>
		<Param type="cascader" multiple="false" text="成果影像分类" name="ImageClassify" value="String" required="true">
			<Datasource type="dictionaryTree" param="DIC_ImageClassification" attr="code">

			</Datasource>
		</Param>
	</Run>
	<Source>
		<Param name="path" display="false" />
	</Source>
</Plugin>'
WHERE f_id=20004;

==> imagedb-api-4.5.0-20251117.032040-122.jar: image/db/sql/V20250223_2__alter_imageImportPlugin.sql <==
--修改成果影像入库插件
UPDATE tbimp_plugin
SET f_name='成果影像解析入库插件', f_group='文件', f_desc='成果影像解析入库插件', f_assembly=NULL, f_classname='com.geoway.imagedb.dataset.plugin.ImageMosaicDatasetImportPlugin', f_detail='<Plugin>
	<Design>

		<Param type="dropbox" multiple="false" text="目标数据库" name="TargetDatabaseKey" hideName="TargetDatabaseName" value="String" required="true">
			<Datasource type="datumDatabase" param="">

			</Datasource>
		</Param>

		<Param type="dropbox" multiple="false" text="目标要素集" name="DatasetId" value="Number" hideName="TargetFeatureDatasetName" required="true">
			<Datasource type="imageDataset" param="${TargetDatabaseKey}">

			</Datasource>
		</Param>

	</Design>
	<Run>
		<Param type="dropbox" multiple="false" text="文件结构模型" name="FileModelId" value="String" required="true">
			<Datasource type="datasetFileModel" param="${DatasetId}" required="true">

			</Datasource>
		</Param>
		<Param type="dropbox" multiple="false" text="存储节点" name="ServiceId" value="String" required="true">
			<Datasource type="datasetFileStorage" param="${DatasetId}" required="true">

			</Datasource>
		</Param>
		<Param type="file" multiple="false" text="数据位置" name="SourceFolderPath" value="String" required="true">
			<Datasource type="enum" param="${ServiceId}">
				<option value="1" text="Folder" />
			</Datasource>
		</Param>
		<Param type="dropbox" multiple="false" text="元数据解析插件" name="MetaPluginInfo" required="false">
			<Datasource type="imageMetaPluginInfo" required="true">

			</Datasource>
		</Param>
		<Param type="datePicker" text="数据时相" name="Time" value="Date" needSecond="false" required="false">

		</Param>
		<Param type="cascader" multiple="false" text="成果影像分类" name="ImageClassify" value="String" required="false">
			<Datasource type="dictionaryTree" param="DIC_ImageClassification" attr="code">

			</Datasource>
		</Param>
	</Run>
	<Source>
		<Param name="path" display="false" />
	</Source>
</Plugin>'
WHERE f_id=20004;
